@@ -84,11 +84,11 @@ class Manifest(object):
     
     def to_string(self, format="xml"):
         if self.altered == False and isinstance(self._output, rdflib.ConjunctiveGraph):
-            return self._output.serialize(format=format) + "u\n"
+            return self._output.serialize(format=format) + "\n"
         self._output = self.get_graph()
         if isinstance(self._output, rdflib.ConjunctiveGraph):
             self.altered = False
-            return self._output.serialize(format=format) + "u\n"
+            return self._output.serialize(format=format) + "\n"
         else:
             return u'<?xml version="1.0" encoding="UTF-8"?>\n'
     
